@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Sequence, Union
 
 from .literals import AuthenticationTypeType, AZStatusType, ServiceUpdateStatusType, SourceTypeType
 
@@ -170,7 +170,7 @@ AuthenticationModeTypeDef = TypedDict(
     "AuthenticationModeTypeDef",
     {
         "Type": Literal["password"],
-        "Passwords": List[str],
+        "Passwords": Sequence[str],
     },
     total=False,
 )
@@ -195,7 +195,7 @@ AvailabilityZoneTypeDef = TypedDict(
 _RequiredBatchUpdateClusterRequestRequestTypeDef = TypedDict(
     "_RequiredBatchUpdateClusterRequestRequestTypeDef",
     {
-        "ClusterNames": List[str],
+        "ClusterNames": Sequence[str],
     },
 )
 _OptionalBatchUpdateClusterRequestRequestTypeDef = TypedDict(
@@ -298,7 +298,7 @@ _OptionalCopySnapshotRequestRequestTypeDef = TypedDict(
     {
         "TargetBucket": str,
         "KmsKeyId": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -327,8 +327,8 @@ _RequiredCreateACLRequestRequestTypeDef = TypedDict(
 _OptionalCreateACLRequestRequestTypeDef = TypedDict(
     "_OptionalCreateACLRequestRequestTypeDef",
     {
-        "UserNames": List[str],
-        "Tags": List["TagTypeDef"],
+        "UserNames": Sequence[str],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -364,16 +364,16 @@ _OptionalCreateClusterRequestRequestTypeDef = TypedDict(
         "NumShards": int,
         "NumReplicasPerShard": int,
         "SubnetGroupName": str,
-        "SecurityGroupIds": List[str],
+        "SecurityGroupIds": Sequence[str],
         "MaintenanceWindow": str,
         "Port": int,
         "SnsTopicArn": str,
         "TLSEnabled": bool,
         "KmsKeyId": str,
-        "SnapshotArns": List[str],
+        "SnapshotArns": Sequence[str],
         "SnapshotName": str,
         "SnapshotRetentionLimit": int,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "SnapshotWindow": str,
         "EngineVersion": str,
         "AutoMinorVersionUpgrade": bool,
@@ -407,7 +407,7 @@ _OptionalCreateParameterGroupRequestRequestTypeDef = TypedDict(
     "_OptionalCreateParameterGroupRequestRequestTypeDef",
     {
         "Description": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -439,7 +439,7 @@ _OptionalCreateSnapshotRequestRequestTypeDef = TypedDict(
     "_OptionalCreateSnapshotRequestRequestTypeDef",
     {
         "KmsKeyId": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -463,14 +463,14 @@ _RequiredCreateSubnetGroupRequestRequestTypeDef = TypedDict(
     "_RequiredCreateSubnetGroupRequestRequestTypeDef",
     {
         "SubnetGroupName": str,
-        "SubnetIds": List[str],
+        "SubnetIds": Sequence[str],
     },
 )
 _OptionalCreateSubnetGroupRequestRequestTypeDef = TypedDict(
     "_OptionalCreateSubnetGroupRequestRequestTypeDef",
     {
         "Description": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -501,7 +501,7 @@ _RequiredCreateUserRequestRequestTypeDef = TypedDict(
 _OptionalCreateUserRequestRequestTypeDef = TypedDict(
     "_OptionalCreateUserRequestRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -763,8 +763,8 @@ DescribeServiceUpdatesRequestRequestTypeDef = TypedDict(
     "DescribeServiceUpdatesRequestRequestTypeDef",
     {
         "ServiceUpdateName": str,
-        "ClusterNames": List[str],
-        "Status": List[ServiceUpdateStatusType],
+        "ClusterNames": Sequence[str],
+        "Status": Sequence[ServiceUpdateStatusType],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -825,7 +825,7 @@ DescribeUsersRequestRequestTypeDef = TypedDict(
     "DescribeUsersRequestRequestTypeDef",
     {
         "UserName": str,
-        "Filters": List["FilterTypeDef"],
+        "Filters": Sequence["FilterTypeDef"],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -891,7 +891,7 @@ FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
         "Name": str,
-        "Values": List[str],
+        "Values": Sequence[str],
     },
 )
 
@@ -998,7 +998,7 @@ _OptionalResetParameterGroupRequestRequestTypeDef = TypedDict(
     "_OptionalResetParameterGroupRequestRequestTypeDef",
     {
         "AllParameters": bool,
-        "ParameterNames": List[str],
+        "ParameterNames": Sequence[str],
     },
     total=False,
 )
@@ -1156,7 +1156,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1191,7 +1191,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1212,8 +1212,8 @@ _RequiredUpdateACLRequestRequestTypeDef = TypedDict(
 _OptionalUpdateACLRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateACLRequestRequestTypeDef",
     {
-        "UserNamesToAdd": List[str],
-        "UserNamesToRemove": List[str],
+        "UserNamesToAdd": Sequence[str],
+        "UserNamesToRemove": Sequence[str],
     },
     total=False,
 )
@@ -1243,7 +1243,7 @@ _OptionalUpdateClusterRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateClusterRequestRequestTypeDef",
     {
         "Description": str,
-        "SecurityGroupIds": List[str],
+        "SecurityGroupIds": Sequence[str],
         "MaintenanceWindow": str,
         "SnsTopicArn": str,
         "SnsTopicStatus": str,
@@ -1278,7 +1278,7 @@ UpdateParameterGroupRequestRequestTypeDef = TypedDict(
     "UpdateParameterGroupRequestRequestTypeDef",
     {
         "ParameterGroupName": str,
-        "ParameterNameValues": List["ParameterNameValueTypeDef"],
+        "ParameterNameValues": Sequence["ParameterNameValueTypeDef"],
     },
 )
 
@@ -1300,7 +1300,7 @@ _OptionalUpdateSubnetGroupRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateSubnetGroupRequestRequestTypeDef",
     {
         "Description": str,
-        "SubnetIds": List[str],
+        "SubnetIds": Sequence[str],
     },
     total=False,
 )
